==> 1.0.8.tar.gz: android/src/main/kotlin/net/xinhuamm/xycloud/xinhuamm_xycloud/XYCloudWebView.kt <==
package net.xinhuamm.xycloud.xinhuamm_xycloud

import android.view.View
import android.view.ViewGroup
import android.widget.FrameLayout
import androidx.fragment.app.Fragment
import androidx.fragment.app.FragmentActivity
import io.flutter.plugin.common.BinaryMessenger
import io.flutter.plugin.platform.PlatformView

/**
 * author : yuntong
 * date   : 2023/11/17 14:32
 * desc   :
 */
class XYCloudWebView(
    context: FragmentActivity,
    messenger: BinaryMessenger,
    viewId: Int,
    args: Any?
) : PlatformView {
    private val view: FrameLayout

    init {
        view = FrameLayout(context)
        val vParams: ViewGroup.LayoutParams = FrameLayout.LayoutParams(
            ViewGroup.LayoutParams.MATCH_PARENT, ViewGroup.LayoutParams.MATCH_PARENT
        )
        view.layoutParams = vParams
        view.id = R.id.xinhuamm_xycloud_id_container
        if (args is Map<*, *>) {
            val urlValue = args["url"]
            if (urlValue is String) {
                val url: String = urlValue
                val fragment: Fragment = XYCloudFragment.newInstance(url)
                val fm = context.supportFragmentManager
                fm.beginTransaction()
                    .replace(view.id, fragment)
                    .commitAllowingStateLoss()
            } else {
                view.addView(XYCloudErrorView(context, args).view)
            }
        } else {
            view.addView(XYCloudErrorView(context, args).view)
        }
    }

    override fun getView(): View {
        return view
    }

    override fun dispose() {
        // 在这里进行资源释放等清理操作
    }
}

==> 1.1.7.tar.gz: android/src/main/kotlin/net/xinhuamm/xycloud/xinhuamm_xycloud/XYCloudWebView.kt <==
package net.xinhuamm.xycloud.xinhuamm_xycloud

import android.view.View
import android.view.ViewGroup
import android.widget.FrameLayout
import androidx.fragment.app.FragmentActivity
import io.flutter.plugin.platform.PlatformView

/**
 * author : yuntong
 * date   : 2023/11/17 14:32
 * desc   :
 */
class XYCloudWebView(
    val context: FragmentActivity,
    val viewId: Int,
    val args: Any?
) : PlatformView {

    private var fragment: XYCloudFragment? = null

    override fun getView(): View {
        val view = FrameLayout(context)
        val vParams: ViewGroup.LayoutParams = FrameLayout.LayoutParams(
            ViewGroup.LayoutParams.MATCH_PARENT, ViewGroup.LayoutParams.MATCH_PARENT
        )
        view.layoutParams = vParams
        view.id = R.id.xinhuamm_xycloud_id_container
        if (args is Map<*, *>) {
            val urlValue = args["url"]
            if (urlValue is String) {
                val url: String = urlValue
                fragment = XYCloudFragment.newInstance(url)
                val fm = context.supportFragmentManager
                fm.beginTransaction()
                    .replace(view.id, fragment!!)
                    .commitAllowingStateLoss()
                XYCloudManager.setNotifyVisibility {
                    if (it) {
                        fragment?.onResume()
                    } else {
                        fragment?.onPause()
                    }
                }
            } else {
                view.addView(XYCloudErrorView(context, args).view)
            }
        } else {
            view.addView(XYCloudErrorView(context, args).view)
        }
        return view
    }

    override fun dispose() {
        fragment?.onDestroy()
    }
}
